@@ -32,6 +32,8 @@
  */
 #define MY_XDR
 
+#define GQA_TYPE_USR USRQUOTA  /* RQUOTA_USRQUOTA */
+#define GQA_TYPE_GRP GRPQUOTA  /* RQUOTA_GRPQUOTA */
 #define GQR_STATUS gqr_status
 #define GQR_RQUOTA gqr_rquota
 
