@@ -33,6 +33,8 @@
 
 #define MNTENT mntent
 
+#define GQA_TYPE_USR USRQUOTA  /* RQUOTA_USRQUOTA */
+#define GQA_TYPE_GRP GRPQUOTA  /* RQUOTA_GRPQUOTA */
 #define GQR_STATUS gqr_status
 #define GQR_RQUOTA gqr_rquota
 
